@@ -6,12 +6,11 @@ use 5.008001;
 use base qw( Exporter);
 use Path::Tiny qw( path );
 use Carp qw( croak );
-use File::Temp qw( tempdir );
 use Test2::API qw( context run_subtest );
 use Capture::Tiny qw( capture_merged );
 use Alien::Build::Util qw( _mirror );
 use List::Util 1.33 qw( any );
-use File::chdir;
+use Alien::Build::Temp;
 
 our @EXPORT = qw(
   alienfile
@@ -30,7 +29,7 @@ our @EXPORT = qw(
 );
 
 # ABSTRACT: Tools for testing Alien::Build + alienfile
-our $VERSION = '1.82_01'; # TRIAL VERSION
+our $VERSION = '1.84_01'; # TRIAL VERSION
 $VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
 
 
@@ -54,10 +53,11 @@ sub alienfile
   require alienfile;
   push @alienfile::EXPORT, 'targ' unless any { /^targ$/ } @alienfile::EXPORT;
 
+  my $temp = Alien::Build::Temp->newdir;
   my $get_temp_root = do{
     my $root; # may be undef;
     sub {
-      $root ||= Path::Tiny->new(tempdir( CLEANUP => 1, DIR => $CWD ));
+      $root ||= Path::Tiny->new($temp);
 
       if(@_)
       {
@@ -106,7 +106,7 @@ sub alienfile
   $ctx->release;
 
   $build_alienfile = $args{filename};
-  $build_root      = $get_temp_root->();
+  $build_root      = $temp;
   $build
 }
 
@@ -431,7 +431,7 @@ sub alien_build_clean
   my $ctx = context();
   if($build_root)
   {
-    foreach my $child ($build_root->children)
+    foreach my $child (path($build_root)->children)
     {
       next if $child->basename eq 'prefix';
       $ctx->note("clean: rm: $child");
@@ -570,6 +570,8 @@ sub alien_resume_ok
 }
 
 
+my $alien_rc_root;
+
 sub alien_rc
 {
   my($code) = @_;
@@ -580,7 +582,10 @@ sub alien_rc
   my(undef, $filename, $line) = caller;
   my $code2 = "use strict; use warnings;\n" .
               '# line ' . $line . ' "' . path($filename)->absolute . "\n$code";
-  my $rc = path(tempdir( CLEANUP => 1 ), 'rc.pl');
+
+  $alien_rc_root ||= Alien::Build::Temp->newdir;
+
+  my $rc = path($alien_rc_root)->child('rc.pl');
   $rc->spew_utf8($code2);
   $ENV{ALIEN_BUILD_RC} = "$rc";
   return 1;
@@ -619,7 +624,7 @@ Test::Alien::Build - Tools for testing Alien::Build + alienfile
 
 =head1 VERSION
 
-version 1.82_01
+version 1.84_01
 
 =head1 SYNOPSIS
 
